==> qtcreator_3.5.1+dfsg.orig.tar.xz: qt-creator-opensource-src-3.5.1+dfsg/src/plugins/bookmarks/bookmarks_global.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BOOKMARKS_GLOBAL_H
#define BOOKMARKS_GLOBAL_H

namespace Bookmarks {
namespace Constants {

const char BOOKMARKS_TOGGLE_ACTION[]      = "Bookmarks.Toggle";
const char BOOKMARKS_MOVEUP_ACTION[]      = "Bookmarks.MoveUp";
const char BOOKMARKS_MOVEDOWN_ACTION[]    = "Bookmarks.MoveDown";
const char BOOKMARKS_EDITNOTE_ACTION[]    = "Bookmarks.EditNote";
const char BOOKMARKS_PREV_ACTION[]        = "Bookmarks.Previous";
const char BOOKMARKS_NEXT_ACTION[]        = "Bookmarks.Next";
const char BOOKMARKS_PREVDIR_ACTION[]     = "Bookmarks.PreviousDirectory";
const char BOOKMARKS_NEXTDIR_ACTION[]     = "Bookmarks.NextDirectory";
const char BOOKMARKS_PREVDOC_ACTION[]     = "Bookmarks.PreviousDocument";
const char BOOKMARKS_NEXTDOC_ACTION[]     = "Bookmarks.NextDocument";
const char BOOKMARKS_TEXT_MARK_CATEGORY[] = "Bookmarks.TextMarkCategory";

const char BOOKMARKS_MENU[]               = "Bookmarks.Menu";
const char BOOKMARKS_CONTEXT[]            = "Bookmarks";

} // namespace Constants
} // namespace Bookmarks

#endif // BOOKMARKS_GLOBAL_H

==> qtcreator_6.0.2.orig.tar.xz: qt-creator-opensource-src-6.0.2/src/plugins/bookmarks/bookmarks_global.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

namespace Bookmarks {
namespace Constants {

const char BOOKMARKS_TOGGLE_ACTION[]      = "Bookmarks.Toggle";
const char BOOKMARKS_EDIT_ACTION[]        = "Bookmarks.Edit";
const char BOOKMARKS_MOVEUP_ACTION[]      = "Bookmarks.MoveUp";
const char BOOKMARKS_MOVEDOWN_ACTION[]    = "Bookmarks.MoveDown";
const char BOOKMARKS_EDITNOTE_ACTION[]    = "Bookmarks.EditNote";
const char BOOKMARKS_PREV_ACTION[]        = "Bookmarks.Previous";
const char BOOKMARKS_NEXT_ACTION[]        = "Bookmarks.Next";
const char BOOKMARKS_PREVDIR_ACTION[]     = "Bookmarks.PreviousDirectory";
const char BOOKMARKS_NEXTDIR_ACTION[]     = "Bookmarks.NextDirectory";
const char BOOKMARKS_PREVDOC_ACTION[]     = "Bookmarks.PreviousDocument";
const char BOOKMARKS_NEXTDOC_ACTION[]     = "Bookmarks.NextDocument";
const char BOOKMARKS_TEXT_MARK_CATEGORY[] = "Bookmarks.TextMarkCategory";

const char BOOKMARKS_MENU[]               = "Bookmarks.Menu";
const char BOOKMARKS_CONTEXT[]            = "Bookmarks";

} // namespace Constants
} // namespace Bookmarks
